'use client';

import { Typography, Box, Container, TextField, InputAdornment, Chip } from '@mui/material';
import Header from './components/Header';
import ElegantButton from './components/ElegantButton';
import { motion } from 'framer-motion';
import SearchIcon from '@mui/icons-material/Search';
import LocationOnIcon from '@mui/icons-material/LocationOn';

const contractTypes = [
  'CDI',
  'CDD',
  'Stage',
  'Alternance',
  'Freelance',
];

export default function Home() {
  return (
    <main>
      <Header />
      
      <Box
        sx={{
          position: 'relative',
          overflow: 'hidden',
          '&::before': {
            content: '""',
            position: 'absolute',
            top: 0,
            left: 0,
            right: 0,
            bottom: 0,
            background: 'radial-gradient(circle at 50% 50%, rgba(0,122,255,0.05) 0%, rgba(255,255,255,0) 70%)',
            zIndex: -1,
          },
        }}
      >
        <Container maxWidth="lg">
          <Box 
            sx={{ 
              display: 'flex', 
              flexDirection: 'column',
              alignItems: 'center',
              textAlign: 'center',
              py: { xs: 6, md: 12 },
              px: 4,
              minHeight: 'calc(100vh - 64px)',
              justifyContent: 'center',
            }}
          >
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.8 }}
            >
              <Typography 
                variant="h1" 
                sx={{ 
                  fontSize: { xs: '2.5rem', md: '4rem' },
                  fontWeight: 700,
                  mb: 3,
                  maxWidth: '1000px',
                  background: 'linear-gradient(45deg, #000000, #007AFF)',
                  WebkitBackgroundClip: 'text',
                  WebkitTextFillColor: 'transparent',
                  lineHeight: 1.2,
                }}
              >
                Trouvez votre prochain emploi tech avec une approche intelligente
              </Typography>
            </motion.div>
            
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.8, delay: 0.2 }}
            >
              <Typography 
                variant="body1" 
                sx={{ 
                  fontSize: { xs: '1.1rem', md: '1.5rem' },
                  color: '#86868B',
                  mb: 6,
                  maxWidth: '800px',
                  lineHeight: 1.6,
                }}
              >
                Découvrez des opportunités qui correspondent vraiment à vos compétences et aspirations
              </Typography>
            </motion.div>
            
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.8, delay: 0.4 }}
            >
              <Box
                sx={{
                  display: 'flex',
                  flexDirection: { xs: 'column', md: 'row' },
                  gap: 2,
                  width: '100%',
                  maxWidth: '800px',
                  mb: 4,
                }}
              >
                <TextField
                  fullWidth
                  placeholder="Métier, compétence, mot-clé..."
                  variant="outlined"
                  InputProps={{
                    startAdornment: (
                      <InputAdornment position="start">
                        <SearchIcon sx={{ color: '#007AFF' }} />
                      </InputAdornment>
                    ),
                    sx: {
                      borderRadius: '12px',
                      backgroundColor: 'white',
                      '&:hover': {
                        backgroundColor: 'rgba(255, 255, 255, 0.9)',
                      },
                      boxShadow: '0 2px 8px rgba(0,0,0,0.05)',
                    }
                  }}
                />
                <TextField
                  fullWidth
                  placeholder="Où ? (Ville, département...)"
                  variant="outlined"
                  InputProps={{
                    startAdornment: (
                      <InputAdornment position="start">
                        <LocationOnIcon sx={{ color: '#007AFF' }} />
                      </InputAdornment>
                    ),
                    sx: {
                      borderRadius: '12px',
                      backgroundColor: 'white',
                      '&:hover': {
                        backgroundColor: 'rgba(255, 255, 255, 0.9)',
                      },
                      boxShadow: '0 2px 8px rgba(0,0,0,0.05)',
                    }
                  }}
                />
              </Box>
              <Box
                sx={{
                  display: 'flex',
                  gap: 1,
                  flexWrap: 'wrap',
                  justifyContent: 'center',
                  mb: 4,
                }}
              >
                {contractTypes.map((type, index) => (
                  <motion.div
                    key={type}
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    transition={{ duration: 0.5, delay: 0.6 + index * 0.1 }}
                  >
                    <Chip
                      label={type}
                      clickable
                      sx={{
                        borderRadius: '8px',
                        backgroundColor: 'white',
                        border: '1px solid rgba(0, 122, 255, 0.2)',
                        '&:hover': {
                          backgroundColor: 'rgba(0, 122, 255, 0.05)',
                          borderColor: '#007AFF',
                        },
                        px: 1,
                      }}
                    />
                  </motion.div>
                ))}
              </Box>
              <ElegantButton
                variant="primary"
                size="large"
                href="/search"
                sx={{ 
                  fontSize: '1.2rem',
                  px: 6,
                  py: 2,
                }}
              >
                Rechercher des offres
              </ElegantButton>
            </motion.div>
          </Box>
        </Container>
      </Box>
    </main>
  );
}
